@@ -1,4 +1,3 @@
-import warnings
 from copy import deepcopy
 from functools import partial
 from typing import Any, Callable, Optional
@@ -7,14 +6,18 @@ import numpy as np
 from numpy import ndarray
 
 from ...element import DiscreteField
-from ..basis import Basis
+from .coo_data import COOData
 
 
 class FormExtraParams(dict):
     """Passed to forms as 'w'."""
 
     def __getattr__(self, attr):
-        return self[attr].value
+        if attr in self:
+            if hasattr(self[attr], 'value'):
+                return self[attr].value
+            return self[attr]
+        raise ValueError
 
 
 class Form:
@@ -24,7 +27,8 @@ class Form:
     def __init__(self,
                  form: Optional[Callable] = None,
                  dtype: type = np.float64,
-                 nthreads: int = 0):
+                 nthreads: int = 0,
+                 inverse: bool = False):
         self.form = form.form if isinstance(form, Form) else form
         self.dtype = dtype
         self.nthreads = nthreads
@@ -41,36 +45,25 @@ class Form:
                               nthreads=self.nthreads)
         return self.assemble(self.kernel(*args))
 
-    def assemble(self,
-                 ubasis: Basis,
-                 vbasis: Optional[Basis] = None,
-                 **kwargs) -> Any:
-        raise NotImplementedError
+    def assemble(self, *args, **kwargs) -> Any:
+        return (COOData(*self._assemble(*args, **kwargs))  # type: ignore
+                .todefault())
+
+    def coo_data(self, *args, **kwargs) -> COOData:
+        return COOData(*self._assemble(*args, **kwargs))  # type: ignore
 
     @staticmethod
-    def dictify(w):
+    def dictify(w, basis):
         """Support additional input formats for 'w'."""
         for k in w:
             if isinstance(w[k], DiscreteField):
                 continue
-            elif isinstance(w[k], ndarray):
+            elif isinstance(w[k], ndarray) and len(w[k].shape) == 2:
                 w[k] = DiscreteField(w[k])
-            elif isinstance(w[k], list):
-                warnings.warn("In future, any additional kwargs to "
-                              "asm() must be of type DiscreteField.",
-                              DeprecationWarning)
-                w[k] = DiscreteField(np.array([z.value for z in w[k]]),
-                                     np.array([z.grad for z in w[k]]))
-            elif isinstance(w[k], tuple):
-                warnings.warn("In future, any additional kwargs to "
-                              "asm() must be of type DiscreteField. "
-                              "In most cases this deprecation is "
-                              "fixed replacing asm(..., w=w) "
-                              "by asm(..., w=DiscreteField(*w)).",
-                              DeprecationWarning)
-                w[k] = DiscreteField(*w[k])
+            elif isinstance(w[k], ndarray) and len(w[k].shape) == 1:
+                w[k] = basis.interpolate(w[k])
             else:
                 raise ValueError("The given type '{}' for the list of extra "
                                  "form parameters w cannot be converted to "
-                                 "DiscreteField.".format(type(w)))
+                                 "DiscreteField.".format(type(w[k])))
         return w
