@@ -40,7 +40,7 @@ class MappingAffine(Mapping):
             # affine mapping inverses
             self.invA = np.empty((dim, dim, nt))
             if dim == 1:
-                self.invA[0, 0] = 1.0 / self.A[0, 0]
+                self.invA[0, 0] = 1. / self.A[0, 0]
             elif dim == 2:
                 self.invA[0, 0] =  self.A[1, 1] / self.detA  # noqa
                 self.invA[0, 1] = -self.A[0, 1] / self.detA
@@ -68,36 +68,56 @@ class MappingAffine(Mapping):
             else:
                 raise Exception("Not implemented for the given dimension.")
 
-        if hasattr(mesh, 'facets'):
-            nf = mesh.facets.shape[1]
-            # initialize the boundary mapping
-            self.B = np.empty((dim, dim - 1, nf))
-            self.c = np.empty((dim, nf))
-
-            for i in range(dim):
-                self.c[i] = mesh.p[i, mesh.facets[0, :]]
-                for j in range(dim-1):
-                    self.B[i, j] = (mesh.p[i, mesh.facets[j + 1, :]] -
-                                    mesh.p[i, mesh.facets[0, :]])
-
-            # area scaling
-            if dim == 1:
-                self.detB = np.ones(nf)
-            elif dim == 2:
-                self.detB = np.sqrt(self.B[0, 0]**2 + self.B[1, 0]**2)
-            elif dim == 3:
-                self.detB = np.sqrt((self.B[1, 0]*self.B[2, 1] -
-                                     self.B[2, 0]*self.B[1, 1])**2 +
-                                    (-self.B[0, 0]*self.B[2, 1] +
-                                     self.B[2, 0]*self.B[0, 1])**2 +
-                                    (self.B[0, 0]*self.B[1, 1] -
-                                     self.B[1, 0]*self.B[0, 1])**2)
-            else:
-                raise Exception("Not implemented for the given dimension.")
-
         self.dim = dim
         self.mesh = mesh  # this is required in ElementH2
 
+    def _init_boundary_mapping(self):
+        """For lazy evaluation of boundary mapping."""
+        dim = self.dim
+        nf = self.mesh.facets.shape[1]
+        # initialize the boundary mapping
+        self._B = np.empty((dim, dim - 1, nf))
+        self._c = np.empty((dim, nf))
+
+        for i in range(dim):
+            self._c[i] = self.mesh.p[i, self.mesh.facets[0]]
+            for j in range(dim - 1):
+                self._B[i, j] = (self.mesh.p[i, self.mesh.facets[j + 1]] -
+                                 self.mesh.p[i, self.mesh.facets[0]])
+
+        # area scaling
+        if dim == 1:
+            self._detB = np.ones(nf)
+        elif dim == 2:
+            self._detB = np.sqrt(self._B[0, 0] ** 2 + self._B[1, 0] ** 2)
+        elif dim == 3:
+            self._detB = np.sqrt((self._B[1, 0] * self._B[2, 1] -
+                                  self._B[2, 0] * self._B[1, 1]) ** 2 +
+                                 (-self._B[0, 0] * self._B[2, 1] +
+                                  self._B[2, 0] * self._B[0, 1]) ** 2 +
+                                 (self._B[0, 0] * self._B[1, 1] -
+                                  self._B[1, 0] * self._B[0, 1]) ** 2)
+        else:
+            raise Exception("Not implemented for the given dimension.")
+
+    @property
+    def B(self):
+        if not hasattr(self, '_B'):
+            self._init_boundary_mapping()
+        return self._B
+
+    @property
+    def c(self):
+        if not hasattr(self, '_c'):
+            self._init_boundary_mapping()
+        return self._c
+
+    @property
+    def detB(self):
+        if not hasattr(self, '_detB'):
+            self._init_boundary_mapping()
+        return self._detB
+
     def F(self, X, tind=None):
         if tind is None:
             A, b = self.A, self.b
@@ -108,8 +128,8 @@ class MappingAffine(Mapping):
             return (np.einsum('ijk,jl', A, X).T + b.T).T
         elif len(X.shape) == 3:
             return (np.einsum('ijk,jkl->ikl', A, X).T + b.T).T
-        else:
-            raise Exception("Wrong dimension of input.")
+
+        raise Exception("Wrong dimension of input.")
 
     def invF(self, x, tind=None):
         if tind is None:
@@ -156,8 +176,8 @@ class MappingAffine(Mapping):
             return (np.einsum('ijk,jl', B, X).T + c.T).T
         elif len(X.shape) == 3:
             return (np.einsum('ijk,jkl->ikl', B, X).T + c.T).T
-        else:
-            raise Exception("Wrong dimension of input.")
+
+        raise Exception("Wrong dimension of input.")
 
     def detDG(self, X, find=None):
         if find is None:
@@ -169,17 +189,17 @@ class MappingAffine(Mapping):
 
     def normals(self, X, tind, find, t2f):
         if self.dim == 1:
-            Nref = np.array([[-1.0],
-                             [1.0]])
+            Nref = np.array([[-1.],
+                             [1.]])
         elif self.dim == 2:
-            Nref = np.array([[0.0, -1.0],
-                             [1.0, 1.0],
-                             [-1.0, 0.0]])
+            Nref = np.array([[0., -1.],
+                             [1., 1.],
+                             [-1., 0.]])
         elif self.dim == 3:
-            Nref = np.array([[0.0, 0.0, -1.0],
-                             [0.0, -1.0, 0.0],
-                             [-1.0, 0.0, 0.0],
-                             [1.0, 1.0, 1.0]])
+            Nref = np.array([[0., 0., -1.],
+                             [0., -1., 0.],
+                             [-1., 0., 0.],
+                             [1., 1., 1.]])
         else:
             raise Exception("Not implemented for the given dimension.")
 
@@ -193,4 +213,4 @@ class MappingAffine(Mapping):
 
         n = np.einsum('ijkl,ik->jkl', invDF, N)
         nlength = np.sqrt(np.sum(n**2, axis=0))
-        return np.einsum('ijk,jk->ijk', n, 1.0/nlength)
+        return np.einsum('ijk,jk->ijk', n, 1. / nlength)
